@@ -31,15 +31,12 @@ use crate::{
     storage::StorageKeyPrefix,
     Config,
     Metadata,
+    PhantomDataSendSync,
 };
 use codec::{
     Decode,
     Encode,
 };
-use core::{
-    convert::TryInto,
-    marker::PhantomData,
-};
 use frame_metadata::RuntimeMetadataPrefixed;
 pub use jsonrpsee::{
     client_transport::ws::{
@@ -99,16 +96,6 @@ pub enum NumberOrHex {
     Hex(U256),
 }
 
-/// RPC list or value wrapper.
-#[derive(Serialize, Deserialize, Debug, PartialEq)]
-#[serde(untagged)]
-pub enum ListOrValue<T> {
-    /// A list of values of given type.
-    List(Vec<T>),
-    /// A single value of given type.
-    Value(T),
-}
-
 /// Alias for the type of a block returned by `chain_getBlock`
 pub type ChainBlock<T> =
     SignedBlock<Block<<T as Config>::Header, <T as Config>::Extrinsic>>;
@@ -123,11 +110,19 @@ impl From<NumberOrHex> for BlockNumber {
     }
 }
 
-impl From<u32> for BlockNumber {
-    fn from(x: u32) -> Self {
-        NumberOrHex::Number(x.into()).into()
+// All unsigned ints can be converted into a BlockNumber:
+macro_rules! into_block_number {
+    ($($t: ty)+) => {
+        $(
+            impl From<$t> for BlockNumber {
+                fn from(x: $t) -> Self {
+                    NumberOrHex::Number(x.into()).into()
+                }
+            }
+        )+
     }
 }
+into_block_number!(u8 u16 u32 u64);
 
 /// Arbitrary properties defined in the chain spec as a JSON object.
 pub type SystemProperties = serde_json::Map<String, serde_json::Value>;
@@ -211,14 +206,14 @@ pub struct ReadProof<Hash> {
 pub struct Rpc<T: Config> {
     /// Rpc client for sending requests.
     pub client: Arc<RpcClient>,
-    marker: PhantomData<T>,
+    _marker: PhantomDataSendSync<T>,
 }
 
 impl<T: Config> Clone for Rpc<T> {
     fn clone(&self) -> Self {
         Self {
             client: self.client.clone(),
-            marker: PhantomData,
+            _marker: PhantomDataSendSync::new(),
         }
     }
 }
@@ -228,7 +223,7 @@ impl<T: Config> Rpc<T> {
     pub fn new(client: RpcClient) -> Self {
         Self {
             client: Arc::new(client),
-            marker: PhantomData,
+            _marker: PhantomDataSendSync::new(),
         }
     }
 
@@ -288,16 +283,11 @@ impl<T: Config> Rpc<T> {
 
     /// Fetch the genesis hash
     pub async fn genesis_hash(&self) -> Result<T::Hash, BasicError> {
-        let block_zero = Some(ListOrValue::Value(NumberOrHex::Number(0)));
+        let block_zero = 0u32;
         let params = rpc_params![block_zero];
-        let list_or_value: ListOrValue<Option<T::Hash>> =
+        let genesis_hash: Option<T::Hash> =
             self.client.request("chain_getBlockHash", params).await?;
-        match list_or_value {
-            ListOrValue::Value(genesis_hash) => {
-                genesis_hash.ok_or_else(|| "Genesis hash not found".into())
-            }
-            ListOrValue::List(_) => Err("Expected a Value, got a List".into()),
-        }
+        genesis_hash.ok_or_else(|| "Genesis hash not found".into())
     }
 
     /// Fetch the metadata
@@ -334,6 +324,17 @@ impl<T: Config> Rpc<T> {
         Ok(self.client.request("system_version", rpc_params![]).await?)
     }
 
+    /// Fetch the current nonce for the given account ID.
+    pub async fn system_account_next_index(
+        &self,
+        account: &T::AccountId,
+    ) -> Result<T::Index, BasicError> {
+        Ok(self
+            .client
+            .request("system_accountNextIndex", rpc_params![account])
+            .await?)
+    }
+
     /// Get a header
     pub async fn header(
         &self,
@@ -349,13 +350,9 @@ impl<T: Config> Rpc<T> {
         &self,
         block_number: Option<BlockNumber>,
     ) -> Result<Option<T::Hash>, BasicError> {
-        let block_number = block_number.map(ListOrValue::Value);
         let params = rpc_params![block_number];
-        let list_or_value = self.client.request("chain_getBlockHash", params).await?;
-        match list_or_value {
-            ListOrValue::Value(hash) => Ok(hash),
-            ListOrValue::List(_) => Err("Expected a Value, got a List".into()),
-        }
+        let block_hash = self.client.request("chain_getBlockHash", params).await?;
+        Ok(block_hash)
     }
 
     /// Get a block hash of the latest finalized block
